import React, { useState } from "react";
import classes from "../assets/styles/generatingFormFields.module.scss";
import MarkdownEditor from "@uiw/react-markdown-editor";
import { parseTotalLinkVideo } from "../hooks/sundry/parseLinkVideo";

const GeneratingFormFields = ({listBlock, listTypeAnswer, answers, updateAnswersForm}) => {

    const getUint8Array = (binary) => {
        let bytesArray = []
        let len = binary.length

        for (let i = 0; i < len; i++) {
            bytesArray.push(binary.charCodeAt(i))
        }
        
        return [new Uint8Array(bytesArray)]
    }

    return (
        listBlock.map((item, i) => 
            <div className={classes.item} key={i}>
                <div className={classes.item__question}>
                    <p className={classes.item__question__text}><MarkdownEditor.Markdown source={`${i + 1}) ${item.question}`}/></p>
                    <p className={classes.item__question__comment}>{item.comment}</p>
                    <div className={classes.item__question__video}>
                        {item.video ? 
                            parseTotalLinkVideo(item.video).check ? 
                                <iframe 
                                    width="300" 
                                    height="150" 
                                    src={parseTotalLinkVideo(item.video).parseLink} 
                                    frameborder="0" 
                                    allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" 
                                    referrerpolicy="strict-origin-when-cross-origin" 
                                    allowfullscreen
                                ></iframe> : 
                            <span className={classes.item__question__video__error}>
                                Данный сервис неподдерживает использование их видео.
                            </span> :
                        <span></span>}
                    </div>
                </div>
                <div className={classes.item__answer}>
                    {
                        listTypeAnswer.find(type => type.id === item.typeAnswer).typeTag({
                            postfix: i, 
                            optionAnswer: item.optionAnswer, 
                            answers: answers ? answers : false, 
                            updateAnswersForm: updateAnswersForm ? updateAnswersForm : false
                        })
                    }
                    {
                        item.file.map(f => <a className={classes.item__answer__file} download={f.name} href={
                            URL.createObjectURL(
                                new Blob(getUint8Array(atob(f.binary)), { type: f.type })
                            )
                        }>{f.name}</a>)
                    }
                </div>
            </div>
        )  
    )
}

export default GeneratingFormFields;